/**
 * arxtools - Tools for modififying ARX archives.
 * Copyright (C) 2005  Hagen Möbius
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

#include "common.h"

#include <iostream>

bool ArgumentsValid(std::vector< std::string > & Arguments)
{
	if((Arguments.size() > 0) && (Arguments[0] == "--information"))
	{
		std::cerr << "arxtouch as part of " PACKAGE_STRING "\n\n";
		std::cerr << "No warranty, whatsoever. Copyright by Hagen Moebius, 2005\n" << std::endl;
		
		return false;
	}
	if((Arguments.size() > 0) && (Arguments[0] == "--version"))
	{
		std::cerr << PACKAGE_VERSION << std::endl;
		
		return false;
	}
	if((Arguments.size() == 0) || (Arguments[0] == "--help"))
	{
		std::cerr << "Usage: arxtouch <arx archive> (<uid>)*\n";
		std::cerr << "uid is a unique identifier for an item in the archive; hex-value\n\n";
		std::cerr << "No warranty, whatsoever. Copyright by Hagen Moebius, 2005\n" << std::endl;
		
		return false;
	}
	
	return true;
}

int main(int argc, char ** argv)
{
	std::vector< std::string > Arguments(argv + 1, argv + argc);
	
	if(ArgumentsValid(Arguments) == false)
	{
		return 1;
	}
	
	Arxx::Archive Archive;
	
	if(bFileExists(Arguments[0]) == true)
	{
		Archive.bLoad(Arguments[0]);
	}
	for(std::vector< std::string >::size_type ArgumentIndex = 1; ArgumentIndex < Arguments.size(); ++ArgumentIndex)
	{
		if(IsHexValue(Arguments[ArgumentIndex]) == true)
		{
			Arxx::u4byte UniqueIdentifier(GetHexValue(Arguments[ArgumentIndex]));
			
			if(Archive.pGetItem(UniqueIdentifier) !=0)
			{
				std::cerr << "Unique ID " << UniqueIdentifier << " already exists in the ARX archive. Skipping ..." << std::endl;
			}
			else
			{
				Arxx::Item * Item(new Arxx::Item(Archive, UniqueIdentifier));
				
				if(Item == 0)
				{
					// just dummy usage to prevent warning
				}
			}
		}
		else
		{
			std::cerr << "Parameter \"" << Arguments[ArgumentIndex] << "\" is not a hexadecimal value. Skipping ..." << std::endl;
		}
	}
	Archive.vSave(Arguments[0]);
}
